@@ -20,13 +20,18 @@ setClass('Extent',
 	),
 	validity = function(object)	{
 		c1 <- (object@xmin <= object@xmax)
-		if (!c1) { stop('invalid extent: xmin >= xmax') }
 		c2 <- (object@ymin <= object@ymax)
+		# fix to not break dependencies
+		if (is.na(c1)) c1 <- TRUE
+		if (is.na(c2)) c2 <- TRUE
+		if (!c1) { stop('invalid extent: xmin >= xmax') }
 		if (!c2) { stop('invalid extent: ymin >= ymax') }
-		v <- c(object@xmin, object@xmax, object@ymin, object@ymax)
-		c3 <- all(!is.infinite(v))
-		if (!c3) { stop('invalid extent: infinite value') }		
-		return(c1 & c2 & c3)
+		return(c1 & c2)
+		# fix to not break dependencies
+		#v <- c(object@xmin, object@xmax, object@ymin, object@ymax)
+		#c3 <- all(!is.infinite(v))
+		#if (!c3) { stop('invalid extent: infinite value') }		
+		#return(c1 & c2 & c3)
 	}
 )
 
@@ -106,7 +111,7 @@ setClass('.RasterFile',
 		open = FALSE
 	),
 	validity = function(object) {
-		c1 <- datanotation %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT1U', 'INT2U', 'FLT4S', 'FLT8S')
+		c1 <- object@datanotation %in% c('LOG1S', 'INT1S', 'INT2S', 'INT4S', 'INT1U', 'INT2U', 'FLT4S', 'FLT8S')
 		return(c1)
 	}
 )
