@@ -155,7 +155,11 @@ function(x, y, fun=NULL, na.rm=FALSE, cellnumbers=FALSE, df=FALSE, layer, nl, fa
 		}		
 
 		lyrs <- layer:(layer+nl-1)
-		colnames(res) <- c('ID', names(x)[lyrs])
+		if (cellnumbers) {
+			colnames(res) <- c("ID", "cell", names(x)[lyrs])
+		} else {
+			colnames(res) <- c("ID", names(x)[lyrs])		
+		}
 		
 		if (any(is.factor(x)) & factors) {
 			v <- res[, -1, drop=FALSE]
@@ -175,14 +179,12 @@ function(x, y, fun=NULL, na.rm=FALSE, cellnumbers=FALSE, df=FALSE, layer, nl, fa
 		}
 	
 		if (!.hasSlot(y, 'data') ) {
-			y <- SpatialLinesDataFrame(y,  res[, -1, drop=FALSE])
+			y <- SpatialLinesDataFrame(y,  res[, -1, drop=FALSE], match.ID=FALSE)
 		} else {
 			y@data <- cbind(y@data,  res[, -1, drop=FALSE])
 		}
 		return(y)
 	}
-	
-	
 	res
 }
 )
