@@ -33,15 +33,15 @@ function(x, y, ..., df=FALSE, sp=FALSE){
 		}
 	}
 	if (sp) {
-		v <- .xyValues(x, coordinates(y), ..., df=TRUE)
-		if (!methods::.hasSlot(y, 'data')) {
+		v <- .xyValues(x, coordinates(y)[,1:2,drop=FALSE], ..., df=TRUE)
+		if (!.hasSlot(y, 'data')) {
 			y <- SpatialPointsDataFrame(y,  v[, -1, drop=FALSE])
 		} else {
 			y@data <- cbind(y@data, v[, -1, drop=FALSE])
 		}
 		return(y)
 	} else {
-		.xyValues(x, coordinates(y), ..., df=df)
+		.xyValues(x, coordinates(y)[,1:2,drop=FALSE], ..., df=df)
 	}
 })
 
