@@ -5,12 +5,6 @@
 # Licence GPL v3
 
 
-	
-if (!isGeneric("zoom")) {
-	setGeneric("zoom", function(x, ...)
-		standardGeneric("zoom"))
-}	
-
 
 setMethod('zoom', signature(x='Raster'), 
 function(x, ext=drawExtent(), maxpixels=100000, layer=1, new=TRUE, useRaster=TRUE, ...) {
@@ -25,7 +19,7 @@ function(x, ext=drawExtent(), maxpixels=100000, layer=1, new=TRUE, useRaster=TRU
 	if (nlayers(x) > 1) { 
 		x <- raster(x, layer) 
 	}
-	if (length(x@legend@colortable) > 0) {
+	if (length(colortable(x)) > 0) {
 		.plotCT(x, maxpixels=maxpixels, ext=ext, ...)
 	} else if (useRaster) {
 		.plotraster2(x, maxpixels=maxpixels, ext=ext, ...) 	
